@@ -118,7 +118,7 @@ extern int h_errno;
 extern int errno;
 
 #if NLS
-#include "../nls/nl_types.h"
+#include "nl_types.h"
 #endif
 
 static void
