@@ -26,7 +26,7 @@ static char sccsid[] = "@(#)rcmd.c	5.17 (Berkeley) 6/27/88";
 #include <sys/stat.h>
 
 #if NLS
-#include "../nls/nl_types.h"
+#include "nl_types.h"
 #endif
 
 int
