@@ -22,7 +22,7 @@ static char sccsid[] = "@(#)rexec.c	5.5 (Berkeley) 6/27/88";
 #include "inetprivate.h"
 
 #if NLS
-#include "../nls/nl_types.h"
+#include "nl_types.h"
 #endif
 
 int	rexecoptions;
