@@ -155,7 +155,7 @@ static struct toktab {
 };
 
 #if NLS
-#include "../nls/nl_types.h"
+#include "nl_types.h"
 #endif
 
 static void
