@@ -155,12 +155,22 @@ vsyslog(pri, fmt, ap)
 	/* output the message to the local logger */
 #if 1
 	/* Use NUL as a message delimiter. */
-	if (write(LogFile, tbuf, cnt + 1) >= 0 || !(LogStat&LOG_CONS))
+	if (write(LogFile, tbuf, cnt + 1) >= 1)
+	{
+		return;
+	}
+	else
+	{
+		/* If the write fails, we try to reconect it next
+		 * time. */
+		closelog ();
+	}
+	if (!(LogStat&LOG_CONS))
+		return;
 #else
 	if (write(LogFile, tbuf, cnt) >= 0 || !(LogStat&LOG_CONS))
-#endif
 		return;
-
+#endif
 	/*
 	 * output the message to the console; don't worry about
 	 * blocking, if console blocks everything will.
@@ -198,8 +208,14 @@ openlog(ident, logstat, logfac)
 		}
 	}
 	if (LogFile != -1 && !connected &&
+#if 0
 	    connect(LogFile, &SyslogAddr, sizeof(SyslogAddr.sa_family)+
 			strlen(SyslogAddr.sa_data)) != -1)
+#else
+	    connect(LogFile, &SyslogAddr, sizeof(SyslogAddr) -
+			sizeof(SyslogAddr.sa_data) +
+			strlen(SyslogAddr.sa_data)) != -1)
+#endif
 		connected = 1;
 }
 
