@@ -327,7 +327,7 @@ exchange (argv)
    long-named options.  */
 
 #if NLS
-#include "../nls/nl_types.h"
+#include "nl_types.h"
 #endif
 
 int
