@@ -63,7 +63,7 @@ static char sccsid[] = "@(#)auth_unix.c 1.19 87/08/11 Copyr 1984 Sun Micro";
 #endif
 
 #if NLS
-#include "../nls/nl_types.h"
+#include "nl_types.h"
 #endif
 
 /*
