@@ -55,7 +55,7 @@ extern char *strcpy();
 #endif
 static char *auth_errmsg();
 #if NLS
-#include "../nls/nl_types.h"
+#include "nl_types.h"
 #endif
 
 static char *buf;
