@@ -66,7 +66,7 @@ static char sccsid[] = "@(#)clnt_tcp.c 1.37 87/10/05 Copyr 1984 Sun Micro";
 #define MCALL_MSG_SIZE 24
 
 #if NLS
-#include "../nls/nl_types.h"
+#include "nl_types.h"
 #endif
 
 extern int errno;
