@@ -73,7 +73,7 @@ static struct xp_ops svcudp_op = {
 extern int errno;
 
 #if NLS
-#include "../nls/nl_types.h"
+#include "nl_types.h"
 #endif
 
 /*
