@@ -27,7 +27,7 @@ Cambridge, MA 02139, USA.  */
 #endif
 
 #if NLS
-#include "../nls/nl_types.h"
+#include "nl_types.h"
 #endif
 
 /* Defined in _siglist.c.  */
