@@ -13,20 +13,23 @@ Library General Public License for more details. */
 
 #include <errno.h>
 #include <math.h>
+#include <fpu_control.h>
 
     
 double pow (x,y)  	
 double x,y;
 {
+  int negative;
+  __volatile__ unsigned short cw, saved_cw;	/* 80387 control word */
+
   if (y == 0.0) return 1.0;
 
-  if (x == 0.0) return 0.0;
+  if (x == 0.0) return (y < 0.0) ? __infnan(EDOM) : 0.0;
 
   if (y == 1.0) return x;
 
   if (x < 0.0) {
     long long tmp;
-    int negative;
 
     tmp = (long long) y; 
 
@@ -39,18 +42,36 @@ double x,y;
     }
 
     x = -x;
-    /* x = y * log2(x) */
-    __asm__ __volatile__ ("fyl2x"
-    			  : "=t" (x) : "0" (x), "u" (y));
-    /* x = 2 ^x */
-    x = pow2 (x);
+    } else {
+	negative = 0;
+    }
 
-    return (negative) ? -x : x;
-  }
+ /*
+  * Inline assembler implements the following algorithm:
+  *
+  * 1 - x' = y *log2(x)
+  * 2 - find x1, x2 where x' = x1 + x2 and |x2| <= 0.5
+  * 3 - x = 2^x2 scaled by x1
+  */
 
-  /* x = y * log2(x) */
-  __asm__ __volatile__ ("fyl2x"
+  __asm__ __volatile__ ("fnstcw %0" : "=m" (cw) : );
+  saved_cw = cw;
+
+  cw &= 0xf3ff;	/* force round to nearest */
+  cw |= 0x003f; /* turn off exceptions (see ANSI/ISO 9989 section 7.5.1) */
+
+  __asm__ __volatile__ ("fldcw %0" : : "m" (cw));
+
+  __asm__ __volatile__ ("fyl2x;fstl %2;frndint;fstl %%st(2);fsubrp;f2xm1;"
+			"fld1;faddp;fscale"
     			  : "=t" (x) : "0" (x), "u" (y));
-  /* return 2 ^x */
-  return pow2 (x);
+
+  /* Restore the control word */
+  __asm__ __volatile__ ("fldcw %0" : : "m" (saved_cw));
+
+  /* Check for results that can not be represented (kludgy): */
+  if (__isinf(x) || __isnan(x))
+    errno = ERANGE;
+
+  return (negative) ? -x : x;
 }
